pub fn load_config(path: &Path) -> Result<(DevrigConfig, String)>Expand description
Load and parse a devrig config file, returning both the parsed config and the raw TOML source text (needed for validation diagnostics with source spans).
pub fn load_config(path: &Path) -> Result<(DevrigConfig, String)>Load and parse a devrig config file, returning both the parsed config and the raw TOML source text (needed for validation diagnostics with source spans).