Module graph

Module graph 

Structs

DependencyResolver
Resolves startup order from the dependency graph declared in a DevrigConfig.
ResourceNode
A node in the unified dependency graph.

Enums

ResourceKind
The kind of resource represented by a node in the dependency graph.